==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Képnézegető</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>A Képnézegető egy képmegtekintő eszköz divatos felülettel és gördülékeny teljesítménnyel.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Képek</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Kép információk</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Alapvető információk</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ez a fájl több oldalt tartalmaz, kérjük használja az Evince alkalmazást az összes oldal megtekintéséhez.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Mappa megnyitása</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nincs engedélye a kép megtekintéséhez</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>A képfájl nem található</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Módosítás dátuma</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Méret</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Fájlméret</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Rögzítés dátuma</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exponálási mód</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exponálási program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exponálási idő</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Vaku</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Nyílás</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fókusztávolság</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximum nyílás</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mérésmód</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Fehér egyensúly</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vaku kompenzáció</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lencse modell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Színtér</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera modell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Méretek</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Címke</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Nincs méretezés</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Oldal illesztése a képhez</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Kép illesztése az oldalhoz</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Méretezés:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milliméter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centiméter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Hüvelyk</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Kép pozíciója</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Méretezés</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Kép beállításai</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Kép beállítások</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Árnyékolók</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Kapcsoló</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Csúszó</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Gyűrű</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>éééé/HH/nn ÓÓ:pp:mpmp</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Írjon be egy új nevet</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Mappa kiválasztása</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Ennek a könyvtárnak a szinkronizálása tiltva van</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Mappa hozzáadása</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Mappaszinkronizáció kezelése</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>A mappalista üres</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Szinkronizálás megszakítása</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Az eszköz eltávolításra került</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ez a mappa nem létezik többé</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Kiszámítás...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Kép megtekintése</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavetítés vége</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Előző képernyő</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Következő képernyő</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyős módból</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Kérjük adjon meg egy új gyorsbillentyűt</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Kép megtekintése</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Alapértelmezések visszaállítása</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavetítés vége</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információk</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavetítési beállítások</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Effekt kiválasztása</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Időtartam kiválasztása</translation>
    </message>
    <message>
        <source>second</source>
        <translation>másodperc</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 méret</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Képkezelés</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 méret</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nem találhatók képfájlok</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>A képfájl nem található</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavetítési beállítások</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Hatás</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Idővonal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás az albumhoz</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Hozzáadás új albumhoz</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyőből</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigációs ablak megjelenítése</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigációs ablak elrejtése</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Összes kép</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Rajzoló</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.10.orig.tar.xz: deepin-image-viewer-5.9.10/src/translations/deepin-image-viewer_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>A képfájl nem található</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Kép megtekintése</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyős módból</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Szöveg kivonat</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Képnézegető</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>A Képnézegető egy képmegtekintő eszköz divatos felülettel és gördülékeny teljesítménnyel.</translation>
    </message>
</context>
</TS>
